@@ -23,21 +23,26 @@ module Flipper
         end
 
         def post
+          read_only if Flipper::UI.configuration.read_only
+
           feature = flipper[feature_name]
           value = params['value'].to_s.strip
+          values = value.split(UI.configuration.actors_separator).map(&:strip).uniq
 
-          if Util.blank?(value)
-            error = Rack::Utils.escape("#{value.inspect} is not a valid actor value.")
+          if values.empty?
+            error = "#{value.inspect} is not a valid actor value."
             redirect_to("/features/#{feature.key}/actors?error=#{error}")
           end
 
-          actor = Flipper::Actor.new(value)
+          values.each do |value|
+            actor = Flipper::Actor.new(value)
 
-          case params['operation']
-          when 'enable'
-            feature.enable_actor actor
-          when 'disable'
-            feature.disable_actor actor
+            case params['operation']
+            when 'enable'
+              feature.enable_actor actor
+            when 'disable'
+              feature.disable_actor actor
+            end
           end
 
           redirect_to("/features/#{feature.key}")
