@@ -1,6 +1,3 @@
-require 'helper'
-require 'flipper/spec/shared_adapter_specs'
-
 RSpec.describe Flipper::Adapters::Memory do
   let(:source) { {} }
   subject { described_class.new(source) }
