@@ -1,5 +1,3 @@
-require 'helper'
-
 RSpec.describe Flipper::UI::Actions::PercentageOfActorsGate do
   let(:token) do
     if Rack::Protection::AuthenticityToken.respond_to?(:random_token)
@@ -30,6 +28,23 @@ RSpec.describe Flipper::UI::Actions::PercentageOfActorsGate do
       end
     end
 
+    context 'with space in feature name' do
+      before do
+        post 'features/sp%20ace/percentage_of_actors',
+             { 'value' => '24', 'authenticity_token' => token },
+             'rack.session' => session
+      end
+
+      it 'enables the feature' do
+        expect(flipper["sp ace"].percentage_of_actors_value).to be(24)
+      end
+
+      it 'redirects back to feature' do
+        expect(last_response.status).to be(302)
+        expect(last_response.headers['Location']).to eq('/features/sp%20ace')
+      end
+    end
+
     context 'with invalid value' do
       before do
         post 'features/search/percentage_of_actors',
@@ -43,7 +58,7 @@ RSpec.describe Flipper::UI::Actions::PercentageOfActorsGate do
 
       it 'redirects back to feature' do
         expect(last_response.status).to be(302)
-        expect(last_response.headers['Location']).to eq('/features/search?error=Invalid+percentage+of+actors+value%3A+value+must+be+a+positive+number+less+than+or+equal+to+100%2C+but+was+555')
+        expect(last_response.headers['Location']).to eq('/features/search?error=Invalid%20percentage%20of%20actors%20value:%20value%20must%20be%20a%20positive%20number%20less%20than%20or%20equal%20to%20100,%20but%20was%20555')
       end
     end
   end
